# -*- coding: utf-8 -*-
from Components.VariableText import VariableText
from Renderer import Renderer

from enigma import eLabel, eTimer
from skin import parseColor

from time import localtime, strftime

class ColorLabelRecordStateClock(VariableText, Renderer):

	def __init__(self):
		Renderer.__init__(self)
		VariableText.__init__(self)
		self.foreColors = []
		self.backColors = []
		self.__get_value = False
		self.timer = None
		self.timeFormat = "%H:%M"

	GUI_WIDGET = eLabel

	def connect(self, source):
		Renderer.connect(self, source)
		self.changed((self.CHANGED_DEFAULT,))

	def changed(self, what):
		if what[0] == self.CHANGED_CLEAR:
			if self.instance:
				self.instance.hide()
		else:
			if self.instance:
				if  self.__get_value:
					self.setColor()
				self.instance.show()
		
	def applySkin(self, desktop, screen):
		if self.skinAttributes:
			attribs = [ ]
			for (attrib, value) in self.skinAttributes:
				if attrib == "backgroundColors":
					for color in value.split(','):
						self.backColors.append(parseColor(color))
				elif attrib == "foregroundColors":
					for color in value.split(','):
						self.foreColors.append(parseColor(color))
				elif attrib == "timeFormat":
						self.timeFormat = value
				else:
					attribs.append((attrib,value))
			self.skinAttributes = attribs
		
		#setcolor at first 
		self.setColor()
		
		return Renderer.applySkin(self, desktop, screen)
	
	def setForegroundColorNum(self, x):
		if self.instance:
			if len(self.foreColors) > x:
				self.instance.setForegroundColor(self.foreColors[x])
				self.instance.invalidate()
			#else:
			#	print "setForegroundColorNum failed!",x
	
	def setBackgroundColorNum(self, x):
		if self.instance:
			if len(self.backColors) > x:
				self.instance.setBackgroundColor(self.backColors[x])
				self.instance.invalidate()
			#else:
			#	print "setBackgroundColorNum failed!",x

	def postWidgetCreate(self, instance):
		self.__get_value = getattr(self.source, "getBoolean", None) != None and True
		instance.show()
		self.setTime()
		
		self.timer = eTimer()
		self.timer_conn = self.timer.timeout.connect(self.setTime)
		self.timer.start(500)

	def setTime(self):
		t = localtime()
		time_txt = strftime(self.timeFormat, t)
		self.instance.setText(time_txt)
		self.instance.invalidate()

	def setColor(self):
		recState = bool(self.source.getBoolean())
		if recState:
			self.setForegroundColorNum(1)
			self.setBackgroundColorNum(1)
		else:
			self.setForegroundColorNum(0)
			self.setBackgroundColorNum(0)

	def destroy(self):
		self.timer_conn = None
		self.timer = None